@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher;
-$WWW::FetchStory::Fetcher::VERSION = '0.25';
+$WWW::FetchStory::Fetcher::VERSION = '0.2501';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.25
+version 0.2501
 
 =head1 DESCRIPTION
 
@@ -282,7 +282,12 @@ sub fetch {
     my @storyfiles = ();
 
     $args{meta_only} = 1 if $args{use_file};
-    if (!$args{meta_only})
+    if ($args{meta_only})
+    {
+        $self->derive_values(info=>\%story_info);
+        warn Dump(\%story_info) if ($self->{verbose} > 1);
+    }
+    else
     {
         if ($args{epub} and exists $story_info{epub_url} and $story_info{epub_url})
         {
